<?php
/**
 * Additional Information options.
 *
 * @package Creativ Agency Pro
 */

$default = creativ_agency_get_default_theme_options();

// Featured Additional Information Section
$wp_customize->add_section( 'section_our_services',
	array(
		'title'      => __( 'Our Services', 'creativ-agency' ),
		'priority'   => 100,
		'capability' => 'edit_theme_options',
		'panel'      => 'home_page_panel',
		)
);
// Disable Additional Information Section
$wp_customize->add_setting('theme_options[disable_our_services_section]', 
	array(
	'default' 			=> $default['disable_our_services_section'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',
	'sanitize_callback' => 'creativ_agency_sanitize_checkbox'
	)
);

$wp_customize->add_control('theme_options[disable_our_services_section]', 
	array(		
	'label' 	=> __('Disable Additional Information Section', 'creativ-agency'),
	'section' 	=> 'section_our_services',
	'settings'  => 'theme_options[disable_our_services_section]',
	'type' 		=> 'checkbox',	
	)
);

// Section Icon
$wp_customize->add_setting('theme_options[our_services_section_icon]', 
	array(
	'default'           => $default['our_services_section_icon'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[our_services_section_icon]', 
	array(
	'label'       => __('Section Icon', 'creativ-agency'),

	'description' => sprintf( __('Please input icon as eg: fab fa-buffer. Find Font Aawesome icons %1$shere%2$s', 'creativ-agency'), '<a href="' . esc_url( 'https://fontawesome.com/icons' ) . '" target="_blank">', '</a>' ),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[our_services_section_icon]',	
	'active_callback' => 'creativ_agency_our_services_active',		
	'type'        => 'text'
	)
);

// Section Title
$wp_customize->add_setting('theme_options[our_services_section_title]', 
	array(
	'default'           => $default['our_services_section_title'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[our_services_section_title]', 
	array(
	'label'       => __('Section Title', 'creativ-agency'),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[our_services_section_title]',	
	'active_callback' => 'creativ_agency_our_services_active',		
	'type'        => 'text'
	)
);

// Section Sub Title
$wp_customize->add_setting('theme_options[our_services_section_subtitle]', 
	array(
	'default'           => $default['our_services_section_subtitle'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'sanitize_text_field'
	)
);

$wp_customize->add_control('theme_options[our_services_section_subtitle]', 
	array(
	'label'       => __('Section Sub Title', 'creativ-agency'),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[our_services_section_subtitle]',	
	'active_callback' => 'creativ_agency_our_services_active',		
	'type'        => 'text'
	)
);

// Number of counter
$wp_customize->add_setting('theme_options[number_of_column]', 
	array(
	'default' 			=> $default['number_of_column'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_column]', 
	array(
	'label'       => __('Column Layout', 'creativ-agency'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 3', 'creativ-agency'),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[number_of_column]',		
	'type'        => 'number',
	'active_callback' => 'creativ_agency_our_services_active',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 3,
			'step'	=> 1,
		),
	)
);

// Number of items
$wp_customize->add_setting('theme_options[number_of_items]', 
	array(
	'default' 			=> $default['number_of_items'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_number_range'
	)
);

$wp_customize->add_control('theme_options[number_of_items]', 
	array(
	'label'       => __('Number Of Items', 'creativ-agency'),
	'description' => __('Save & Refresh the customizer to see its effect. Maximum is 3.', 'creativ-agency'),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[number_of_items]',		
	'type'        => 'number',
	'active_callback' => 'creativ_agency_our_services_active',
	'input_attrs' => array(
			'min'	=> 1,
			'max'	=> 3,
			'step'	=> 1,
		),
	)
);

$wp_customize->add_setting('theme_options[ad_content_type]', 
	array(
	'default' 			=> $default['ad_content_type'],
	'type'              => 'theme_mod',
	'capability'        => 'edit_theme_options',	
	'sanitize_callback' => 'creativ_agency_sanitize_select'
	)
);

$wp_customize->add_control('theme_options[ad_content_type]', 
	array(
	'label'       => __('Content Type', 'creativ-agency'),
	'section'     => 'section_our_services',   
	'settings'    => 'theme_options[ad_content_type]',		
	'type'        => 'select',
	'active_callback' => 'creativ_agency_our_services_active',
	'choices'	  => array(
			'ad_page'	  	=> __('Page','creativ-agency'),
			'ad_post'	  	=> __('Post','creativ-agency'),
		),
	)
);

$number_of_items = creativ_agency_get_option( 'number_of_items' );

for( $i=1; $i<=$number_of_items; $i++ ){

	// Icon
	$wp_customize->add_setting('theme_options[our_services_icon_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'sanitize_text_field'
		)
	);

	$wp_customize->add_control('theme_options[our_services_icon_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Icon #%1$s', 'creativ-agency'), $i),
		'description' => sprintf( __('Please input icon as eg: fab fa-buffer. Find Font Aawesome icons %1$shere%2$s', 'creativ-agency'), '<a href="' . esc_url( 'https://fontawesome.com/icons' ) . '" target="_blank">', '</a>' ),
		'section'     => 'section_our_services',   
		'settings'    => 'theme_options[our_services_icon_'.$i.']',		
		'active_callback' => 'creativ_agency_our_services_active',			
		'type'        => 'text',
		)
	);

	// Page
	$wp_customize->add_setting('theme_options[our_services_page_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'creativ_agency_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[our_services_page_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Page #%1$s', 'creativ-agency'), $i),
		'section'     => 'section_our_services',   
		'settings'    => 'theme_options[our_services_page_'.$i.']',		
		'type'        => 'dropdown-pages',
		'active_callback' => 'creativ_agency_our_services_page',
		)
	);

	// Posts
	$wp_customize->add_setting('theme_options[our_services_post_'.$i.']', 
		array(
		'type'              => 'theme_mod',
		'capability'        => 'edit_theme_options',	
		'sanitize_callback' => 'creativ_agency_dropdown_pages'
		)
	);

	$wp_customize->add_control('theme_options[our_services_post_'.$i.']', 
		array(
		'label'       => sprintf( __('Select Post #%1$s', 'creativ-agency'), $i),
		'section'     => 'section_our_services',   
		'settings'    => 'theme_options[our_services_post_'.$i.']',		
		'type'        => 'select',
		'choices'	  => creativ_agency_dropdown_posts(),
		'active_callback' => 'creativ_agency_our_services_post',
		)
	);
}
